## 4.0.0.20240205 (2024-02-05)

A new shade of Black (#11362)

## 4.0.0.7 (2023-11-10)

Complete Flask-Migrate and mark as Strict (#10971)

## 4.0.0.6 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 4.0.0.5 (2023-07-08)

Remove `SQLAlchemy` stubs (#10389)

Co-authored-by: AlexWaygood <alex.waygood@gmail.com>

## 4.0.0.4 (2023-05-10)

Add `partial_stub` metadata field (#10157)

## 4.0.0.3 (2023-03-27)

Add defaults for third-party stubs E-H (#9954)

## 4.0.0.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 4.0.0.1 (2023-01-13)

`Flask-Migrate`: Add `Flask` as a dependency (#9517)

## 4.0.0.0 (2022-11-23)

Add stubs for flask-migrate (#8967)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

